aboutsummaryrefslogtreecommitdiff
path: root/src/main/java/gregtech/api/enums/GT_Values.java
diff options
context:
space:
mode:
authorAntifluxfield <lyj_299792458@163.com>2017-12-12 21:10:29 +0800
committerAntifluxfield <lyj_299792458@163.com>2017-12-12 21:10:29 +0800
commit22fb5955b0356a9b174312a6300348446a523f5c (patch)
tree594feea7970baa612d517d19a1fcb95144ab369f /src/main/java/gregtech/api/enums/GT_Values.java
parent0cce0e6a1af627fe536aa11097373c17547c242b (diff)
parent79999604ecb7795cafca5dac21f8df33f8da62ee (diff)
downloadGT5-Unofficial-22fb5955b0356a9b174312a6300348446a523f5c.tar.gz
GT5-Unofficial-22fb5955b0356a9b174312a6300348446a523f5c.tar.bz2
GT5-Unofficial-22fb5955b0356a9b174312a6300348446a523f5c.zip
Merge remote-tracking branch 'origin/experimental' into GT6-pipes
Diffstat (limited to 'src/main/java/gregtech/api/enums/GT_Values.java')
-rw-r--r--src/main/java/gregtech/api/enums/GT_Values.java65
1 files changed, 39 insertions, 26 deletions
diff --git a/src/main/java/gregtech/api/enums/GT_Values.java b/src/main/java/gregtech/api/enums/GT_Values.java
index d6fae23b01..94d268fd58 100644
--- a/src/main/java/gregtech/api/enums/GT_Values.java
+++ b/src/main/java/gregtech/api/enums/GT_Values.java
@@ -117,36 +117,49 @@ public class GT_Values {
* For Internal Usage (Network)
*/
public static IGT_NetworkHandler NW;
- /**
- * Control percentage of filled 3x3 chunks. Lower number means less oreveins spawn
- */
- public static int oreveinPercentage;
- /**
- * Control number of attempts to find a valid orevein. Lower numbers is slightly faster chunkgen, but more empty chunks with thin stone height.
- */
- public static int oreveinAttempts;
- /**
+ /**
+ * Control percentage of filled 3x3 chunks. Lower number means less oreveins spawn
+ */
+ public static int oreveinPercentage;
+ /**
+ * Control number of attempts to find a valid orevein. Generally this maximum limit isn't hit, selecting a vein is cheap
+ */
+ public static int oreveinAttempts;
+ /**
+ * Control number of attempts to place a valid orevein. If a vein wasn't placed due to height restrictions, completely in the water, etc, another attempt is tried.
+ */
+ public static int oreveinMaxPlacementAttempts;
+ /**
+ * How wide to look for oreveins that affect a requested chunk. Trying to use oreveins larger than this will not work correctly. Increasing the size will cause additional worldgenerator lag.
+ * Disabled for now, using 64 in Deep Dark, 32 elsewhere
+ */
+ // public static int oreveinMaxSize;
+ /**
* Not really Constants, but they set using the Config and therefore should be constant (those are for the Debug Mode)
*/
public static boolean D1 = false, D2 = false;
- /**
- * Debug parameter for cleanroom testing.
- */
- public static boolean debugCleanroom = false;
- /**
- * Debug parameter for world generation. Tracks chunks added/removed from run queue.
- */
- public static boolean debugWorldGen = false;
- /**
- * Debug parameter for orevein generation.
- */
- public static boolean debugOrevein = false;
- /**
- * Debug parameter for small ore generation.
- */
- public static boolean debugSmallOres = false;
+ /**
+ * Debug parameter for cleanroom testing.
+ */
+ public static boolean debugCleanroom = false;
+ /**
+ * Debug parameter for world generation. Tracks chunks added/removed from run queue.
+ */
+ public static boolean debugWorldGen = false;
+ /**
+ * Debug parameter for orevein generation.
+ */
+ public static boolean debugOrevein = false;
+ /**
+ * Debug parameter for small ore generation.
+ */
+ public static boolean debugSmallOres = false;
+ /**
+ * Debug parameter for stones generation.
+ */
+ public static boolean debugStones = false;
/**
* If you have to give something a World Parameter but there is no World... (Dummy World)
*/
public static World DW;
-} \ No newline at end of file
+}